@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 
 """Test telegram_menu package."""
 
@@ -6,25 +6,30 @@ import datetime
 import logging
 import time
 import unittest
-from typing import Any, List
+from typing import Any, List, Optional, Union
 
-from telegram_menu import BaseMessage, ButtonType, KeyboardContent, MenuButton, NavigationManager, SessionManager
+import emoji
+
+from telegram_menu import BaseMessage, ButtonType, MenuButton, NavigationHandler, TelegramMenuSession
 
 # this is a testing key, do not use it in production!
 API_KEY = "872134523:AAEe0_y78tnYYEWNUn2QRahnd48rjKhsxSA"
 
+KeyboardContent = List[Union[str, List[str]]]
+
 
 class OptionsAppMessage(BaseMessage):
     """Options app message, show an example of a button with inline buttons."""
 
     LABEL = "options"
 
-    def __init__(self, navigation: NavigationManager, update_callback: List[Any]) -> None:
+    def __init__(self, navigation: NavigationHandler, update_callback: Optional[List[Any]] = None) -> None:
         """Init OptionsAppMessage class."""
         super().__init__(navigation, OptionsAppMessage.LABEL, inlined=True)
 
         self.play_pause = True
-        update_callback.append(self.app_update_display)
+        if update_callback:
+            update_callback.append(self.app_update_display)
 
     def app_update_display(self) -> None:
         """Update message content when callback triggered."""
@@ -46,7 +51,7 @@ class OptionsAppMessage(BaseMessage):
         """Display any text data."""
         self.play_pause = not self.play_pause
         data: KeyboardContent = [["text1", "value1"], ["text2", "value2"]]
-        return self.format_list_to_html(data)
+        return format_list(data)
 
     def picture_button(self) -> str:
         """Display a picture."""
@@ -62,19 +67,28 @@ class OptionsAppMessage(BaseMessage):
         """Display poll answer."""
         logging.info("Answer is %s", poll_answer)
 
-    def content_updater(self) -> str:
+    def update(self) -> str:
         """Update message content."""
         poll_question = "Select one option:"
         poll_choices = ["Option1", "Option2", "Option3", "Option4", "Option5", "Option6", "Option7", "Option8"]
         play_pause_button = "play_button" if self.play_pause else "pause_button"
         self.keyboard = [
-            MenuButton(self.emojize(play_pause_button), self.action_button),
-            MenuButton(self.emojize("twisted_rightwards_arrows"), self.action_button),
-            MenuButton(self.emojize("chart_with_upwards_trend"), self.picture_button, ButtonType.PICTURE),
-            MenuButton(self.emojize("chart_with_downwards_trend"), self.picture_button2, ButtonType.PICTURE),
-            MenuButton(self.emojize("door"), self.text_button, ButtonType.MESSAGE),
-            MenuButton(self.emojize("speaker_medium_volume"), self.action_button),
-            MenuButton(self.emojize("question"), self.action_poll, ButtonType.POLL, args=[poll_question, poll_choices]),
+            MenuButton(label=emojize(play_pause_button), callback=self.action_button),
+            MenuButton(label=emojize("twisted_rightwards_arrows"), callback=self.action_button),
+            MenuButton(
+                label=emojize("chart_with_upwards_trend"), callback=self.picture_button, btype=ButtonType.PICTURE
+            ),
+            MenuButton(
+                label=emojize("chart_with_downwards_trend"), callback=self.picture_button2, btype=ButtonType.PICTURE
+            ),
+            MenuButton(label=emojize("door"), callback=self.text_button, btype=ButtonType.MESSAGE),
+            MenuButton(label=emojize("speaker_medium_volume"), callback=self.action_button),
+            MenuButton(
+                label=emojize("question"),
+                callback=self.action_poll,
+                btype=ButtonType.POLL,
+                args=[poll_question, poll_choices],
+            ),
         ]
         return "Status updated!"
 
@@ -84,7 +98,7 @@ class ActionAppMessage(BaseMessage):
 
     LABEL = "action"
 
-    def __init__(self, navigation: NavigationManager) -> None:
+    def __init__(self, navigation: NavigationHandler) -> None:
         """Init ActionAppMessage class."""
         super().__init__(
             navigation,
@@ -94,7 +108,7 @@ class ActionAppMessage(BaseMessage):
             home_after=True,
         )
 
-    def content_updater(self) -> str:
+    def update(self) -> str:
         """Update message content."""
         return "<code>Action!</code>"
 
@@ -104,7 +118,7 @@ class SecondMenuMessage(BaseMessage):
 
     LABEL = "second_message"
 
-    def __init__(self, navigation: NavigationManager, update_callback: List[Any]) -> None:
+    def __init__(self, navigation: NavigationHandler, update_callback: Optional[List[Any]] = None) -> None:
         """Init SecondMenuMessage class."""
         super().__init__(
             navigation, SecondMenuMessage.LABEL, notification=False, expiry_period=datetime.timedelta(seconds=5)
@@ -112,11 +126,12 @@ class SecondMenuMessage(BaseMessage):
 
         action_message = ActionAppMessage(self._navigation)
         option_message = OptionsAppMessage(self._navigation, update_callback)
-        self.add_button("Option", option_message)
-        self.add_button("Action", action_message)
-        self.add_button("Back")
-        self.add_button("Home")
-        update_callback.append(self.app_update_display)
+        self.add_button(label="Option", callback=option_message)
+        self.add_button(label="Action", callback=action_message)
+        self.add_button(label="Back")
+        self.add_button(label="Home")
+        if update_callback:
+            update_callback.append(self.app_update_display)
 
     def app_update_display(self) -> None:
         """Update message content when callback triggered."""
@@ -124,7 +139,7 @@ class SecondMenuMessage(BaseMessage):
         if edited:
             self.is_alive()
 
-    def content_updater(self) -> str:
+    def update(self) -> str:
         """Update message content."""
         return "Second message"
 
@@ -134,17 +149,17 @@ class StartMessage(BaseMessage):
 
     LABEL = "start"
 
-    def __init__(self, navigation: NavigationManager, update_callback: List[Any]) -> None:
+    def __init__(self, navigation: NavigationHandler, update_callback: Optional[List[Any]] = None) -> None:
         """Init StartMessage class."""
         super().__init__(navigation, StartMessage.LABEL)
 
         # define menu buttons
         action_message = ActionAppMessage(navigation)
         second_menu = SecondMenuMessage(navigation, update_callback)
-        self.add_button("Action", action_message)
-        self.add_button("Second menu", second_menu)
+        self.add_button(label="Action", callback=action_message)
+        self.add_button(label="Second menu", callback=second_menu)
 
-    def content_updater(self) -> str:
+    def update(self) -> str:
         """Update message content."""
         return "Start message!"
 
@@ -155,17 +170,17 @@ class Test(unittest.TestCase):
     def test_wrong_api_key(self) -> None:
         """Test starting a client with wrong key."""
         with self.assertRaises(AttributeError):
-            SessionManager(None)  # type: ignore
+            TelegramMenuSession(None)  # type: ignore
 
         with self.assertRaises(AttributeError):
-            SessionManager(1234)  # type: ignore
+            TelegramMenuSession(1234)  # type: ignore
 
         with self.assertRaises(AttributeError):
-            SessionManager("1234:5678")
+            TelegramMenuSession("1234:5678")
 
     def test_bad_start_message(self) -> None:
         """Test starting a client with bad start message."""
-        manager = SessionManager(API_KEY)
+        manager = TelegramMenuSession(API_KEY)
 
         with self.assertRaises(AttributeError):
             manager.start(MenuButton)
@@ -178,12 +193,12 @@ class Test(unittest.TestCase):
     def test_client_connection(self) -> None:
         """Run the client test."""
         init_logger()
+
         update_callback: List[Any] = []
+        session: Optional["NavigationHandler"] = None
 
-        manager = SessionManager(API_KEY)
-        manager.start(StartMessage, update_callback)
-
-        session = None
+        manager = TelegramMenuSession(api_key=API_KEY)
+        manager.start(start_message_class=StartMessage, start_message_args=update_callback)
         while not session:
             session = manager.get_session()
             time.sleep(1)
@@ -192,6 +207,7 @@ class Test(unittest.TestCase):
         manager.broadcast_picture("picture_path")
         msg_id = session.select_menu_button("Action")
         self.assertGreater(msg_id, 1)
+
         time.sleep(0.5)
         manager.broadcast_message("Test message")
         time.sleep(0.5)
@@ -237,3 +253,41 @@ def init_logger() -> None:
     # start scheduler
     logging.getLogger("apscheduler.scheduler").setLevel(logging.ERROR)
     logging.getLogger("apscheduler.executors").setLevel(logging.ERROR)
+
+
+def format_list(args_array: KeyboardContent) -> str:
+    """Format array of strings in html, first element bold.
+
+    Args:
+        args_array: text content
+
+    Returns:
+        Message content as formatted string
+
+    """
+    content = ""
+    for line in args_array:
+        if not isinstance(line, list):
+            content += f"<b>{line}</b>"
+            continue
+        if line[0]:
+            content += f"<b>{line[0]}</b>"
+            if line[1]:
+                content += ": "
+        if line[1]:
+            content += line[1]
+        content += "\n"
+    return content
+
+
+def emojize(emoji_name: str) -> str:
+    """Get utf-16 code for emoji, defined in https://www.webfx.com/tools/emoji-cheat-sheet/.
+
+    Args:
+        emoji_name: emoji label
+
+    Returns:
+        emoji encoded as string
+
+    """
+    return emoji.emojize(f":{emoji_name}:", use_aliases=True)
